@@ -722,7 +722,7 @@ class Connection(object):
             if self.unix_socket and self.host in ('localhost', '127.0.0.1'):
                 sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
                 addr = self.unix_socket
-                self.host_info = "Localhost via UNIX socket"
+                self.host_info = "Localhost via UNIX socket: " + self.unix_socket
             else:
                 sock = socket.socket()
                 sock.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
@@ -738,6 +738,8 @@ class Connection(object):
             yield self._get_server_information()
             yield self._request_authentication()
 
+            self.connected_time = self.io_loop.time()
+
             if self.sql_mode is not None:
                 yield self.query("SET sql_mode=%s" % (self.sql_mode,))
 
